@@ -19,10 +19,11 @@
 
 #include "kfileitemclipboard.h"
 
+#include <KUrlMimeData>
+
 #include <QApplication>
 #include <QClipboard>
 #include <QMimeData>
-#include <KUrlMimeData>
 
 class KFileItemClipboardSingleton
 {
@@ -74,7 +75,7 @@ void KFileItemClipboard::updateCutItems()
 }
 
 KFileItemClipboard::KFileItemClipboard() :
-    QObject(0),
+    QObject(nullptr),
     m_cutItems()
 {
     updateCutItems();
