@@ -20,10 +20,12 @@
 #include "informationpanel.h"
 
 #include "informationpanelcontent.h"
+
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KJobWidgets>
 #include <KDirNotify>
+
 #include <QApplication>
 #include <QShowEvent>
 #include <QVBoxLayout>
@@ -198,7 +200,7 @@ void InformationPanel::showItemInfo()
 
 void InformationPanel::slotFolderStatFinished(KJob* job)
 {
-    m_folderStatJob = 0;
+    m_folderStatJob = nullptr;
     const KIO::UDSEntry entry = static_cast<KIO::StatJob*>(job)->statResult();
     m_content->showItem(KFileItem(entry, m_shownUrl));
 }
@@ -296,7 +298,7 @@ void InformationPanel::slotLeftDirectory(const QString& directory)
 void InformationPanel::cancelRequest()
 {
     delete m_folderStatJob;
-    m_folderStatJob = 0;
+    m_folderStatJob = nullptr;
 
     m_infoTimer->stop();
     m_resetUrlTimer->stop();
