@@ -711,7 +711,7 @@ void DolphinView::stopLoading()
 
 void DolphinView::updatePalette()
 {
-    QColor color = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+    QColor color = KColorScheme(isActiveWindow() ? QPalette::Active : QPalette::Inactive, KColorScheme::View).background().color();
     if (!m_active) {
         color.setAlpha(150);
     }
@@ -740,6 +740,11 @@ bool DolphinView::eventFilter(QObject* watched, QEvent* event)
         QPixmapCache::clear();
         break;
 
+    case QEvent::WindowActivate:
+    case QEvent::WindowDeactivate:
+        updatePalette();
+        break;
+
     case QEvent::KeyPress:
         if (GeneralSettings::useTabForSwitchingSplitView()) {
             QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
